import type { ServiceContext } from "../ServiceContext.js";
import type { BaseSelector } from "./base.js";
export declare const getSelectorFromContext: (serviceContext: ServiceContext, isMulti?: boolean) => BaseSelector;
