import type { IndexStruct } from "../../indices/IndexStruct.js";
import type { BaseKVStore } from "../kvStore/types.js";
import { BaseIndexStore } from "./types.js";
export declare class KVIndexStore extends BaseIndexStore {
    private _kvStore;
    private _collection;
    constructor(kvStore: BaseKVStore, namespace?: string);
    addIndexStruct(indexStruct: IndexStruct): Promise<void>;
    deleteIndexStruct(key: string): Promise<void>;
    getIndexStruct(structId?: string): Promise<IndexStruct | undefined>;
    getIndexStructs(): Promise<IndexStruct[]>;
}
