export const emptyLogger = Object.freeze({
    log: ()=>{},
    error: ()=>{},
    warn: ()=>{}
});
export const consoleLogger = Object.freeze({
    log: console.log.bind(console),
    error: console.error.bind(console),
    warn: console.warn.bind(console)
});
