import type { BaseNode } from "../../Node.js";
import type { BaseDocumentStore } from "../../storage/docStore/types.js";
export declare function classify(docStore: BaseDocumentStore, nodes: BaseNode[]): Promise<{
    dedupedNodes: BaseNode<import("../../Node.js").Metadata>[];
    missingDocs: string[];
    unusedDocs: string[];
}>;
