import type { BaseEmbedding } from "../../embeddings/index.js";
export declare function getEmbeddedModel(): BaseEmbedding;
export declare function setEmbeddedModel(embeddedModel: BaseEmbedding): void;
export declare function withEmbeddedModel<Result>(embeddedModel: BaseEmbedding, fn: () => Result): Result;
