import { BaseEmbedding } from "./types.js";
export declare enum MistralAIEmbeddingModelType {
    MISTRAL_EMBED = "mistral-embed"
}
export declare class MistralAIEmbedding extends BaseEmbedding {
    model: MistralAIEmbeddingModelType;
    apiKey?: string;
    private session;
    constructor(init?: Partial<MistralAIEmbedding>);
    private getMistralAIEmbedding;
    getTextEmbedding(text: string): Promise<number[]>;
}
