import type { BaseNode } from "../../Node.js";
import { ObjectType } from "../../Node.js";
declare const TYPE_KEY = "__type__";
declare const DATA_KEY = "__data__";
type DocJson = {
    [TYPE_KEY]: ObjectType;
    [DATA_KEY]: string;
};
export declare function isValidDocJson(docJson: any): docJson is DocJson;
export declare function docToJson(doc: BaseNode): DocJson;
export declare function jsonToDoc(docDict: DocJson): BaseNode;
export {};
