import type { Document } from "../Node.js";
import type { BaseRetriever } from "../Retriever.js";
import type { TransformComponent } from "../ingestion/types.js";
import type { BaseNodePostprocessor } from "../postprocessors/types.js";
import type { BaseSynthesizer } from "../synthesizers/types.js";
import type { QueryEngine } from "../types.js";
import type { CloudRetrieveParams } from "./LlamaCloudRetriever.js";
import type { CloudConstructorParams } from "./types.js";
export declare class LlamaCloudIndex {
    params: CloudConstructorParams;
    constructor(params: CloudConstructorParams);
    static fromDocuments(params: {
        documents: Document[];
        transformations?: TransformComponent[];
        verbose?: boolean;
    } & CloudConstructorParams): Promise<LlamaCloudIndex>;
    asRetriever(params?: CloudRetrieveParams): BaseRetriever;
    asQueryEngine(params?: {
        responseSynthesizer?: BaseSynthesizer;
        preFilters?: unknown;
        nodePostprocessors?: BaseNodePostprocessor[];
    } & CloudRetrieveParams): QueryEngine;
}
