import type { NodeWithScore } from "../../Node.js";
import type { MessageContent } from "../../llm/types.js";
import type { BaseNodePostprocessor } from "../types.js";
interface JinaAIRerankerResult {
    index: number;
    document?: {
        text?: string;
    };
    relevance_score: number;
}
export declare class JinaAIReranker implements BaseNodePostprocessor {
    model: string;
    topN?: number;
    apiKey?: string;
    constructor(init?: Partial<JinaAIReranker>);
    rerank(query: string, documents: string[], topN?: number | undefined): Promise<JinaAIRerankerResult[]>;
    postprocessNodes(nodes: NodeWithScore[], query?: MessageContent): Promise<NodeWithScore[]>;
}
export {};
