import { MetadataMode, type BaseNode } from "../Node.js";
import type { SimplePrompt } from "../Prompt.js";
import type { MessageContentDetail } from "../llm/types.js";
export declare function createMessageContent(prompt: SimplePrompt, nodes: BaseNode[], extraParams?: Record<string, string | undefined>, metadataMode?: MetadataMode): Promise<MessageContentDetail[]>;
