import type { DataType } from "../kvStore/SimpleKVStore.js";
import type { BaseInMemoryKVStore } from "../kvStore/types.js";
import { KVIndexStore } from "./KVIndexStore.js";
export declare class SimpleIndexStore extends KVIndexStore {
    private kvStore;
    constructor(kvStore?: BaseInMemoryKVStore);
    static fromPersistDir(persistDir?: string): Promise<SimpleIndexStore>;
    static fromPersistPath(persistPath: string): Promise<SimpleIndexStore>;
    persist(persistPath?: string): Promise<void>;
    static fromDict(saveDict: DataType): SimpleIndexStore;
    toDict(): Record<string, unknown>;
}
