type PromptsDict = Record<string, any>;
type ModuleDict = Record<string, any>;
export declare class PromptMixin {
    /**
     * Validates the prompt keys and module keys
     * @param promptsDict
     * @param moduleDict
     */
    validatePrompts(promptsDict: PromptsDict, moduleDict: ModuleDict): void;
    /**
     * Returns all prompts from the mixin and its modules
     */
    getPrompts(): PromptsDict;
    /**
     * Updates the prompts in the mixin and its modules
     * @param promptsDict
     */
    updatePrompts(promptsDict: PromptsDict): void;
    protected _getPrompts(): PromptsDict;
    protected _getPromptModules(): Record<string, any>;
    protected _updatePrompts(promptsDict: PromptsDict): void;
}
export {};
