export declare enum Tokenizers {
    CL100K_BASE = "cl100k_base"
}
/**
 * @internal Helper class singleton
 */
declare class GlobalsHelper {
    defaultTokenizer: {
        encode: (text: string) => Uint32Array;
        decode: (tokens: Uint32Array) => string;
    };
    constructor();
    tokenizer(encoding?: Tokenizers): (text: string) => Uint32Array;
    tokenizerDecoder(encoding?: Tokenizers): (tokens: Uint32Array) => string;
}
export declare const globalsHelper: GlobalsHelper;
export {};
