import { DEFAULT_INDEX_STORE_PERSIST_FILENAME, DEFAULT_PERSIST_DIR } from "../constants.js";
const defaultPersistPath = `${DEFAULT_PERSIST_DIR}/${DEFAULT_INDEX_STORE_PERSIST_FILENAME}`;
export class BaseIndexStore {
    async persist(persistPath = defaultPersistPath) {
    // Persist the index store to disk.
    }
}
