export declare const defaultUserPrompt: ({ query, referenceAnswer, generatedAnswer, }: {
    query: string;
    referenceAnswer: string;
    generatedAnswer: string;
}) => string;
export type UserPrompt = typeof defaultUserPrompt;
export declare const defaultCorrectnessSystemPrompt: () => string;
export type CorrectnessSystemPrompt = typeof defaultCorrectnessSystemPrompt;
export declare const defaultFaithfulnessRefinePrompt: ({ query, context, existingAnswer, }: {
    query: string;
    context: string;
    existingAnswer: string;
}) => string;
export type FaithfulnessRefinePrompt = typeof defaultFaithfulnessRefinePrompt;
export declare const defaultFaithfulnessTextQaPrompt: ({ query, context, }: {
    query: string;
    context: string;
}) => string;
export type FaithfulnessTextQAPrompt = typeof defaultFaithfulnessTextQaPrompt;
export declare const defaultRelevancyEvalPrompt: ({ query, context, }: {
    query: string;
    context: string;
}) => string;
export type RelevancyEvalPrompt = typeof defaultRelevancyEvalPrompt;
export declare const defaultRelevancyRefinePrompt: ({ query, existingAnswer, contextMsg, }: {
    query: string;
    existingAnswer: string;
    contextMsg: string;
}) => string;
export type RelevancyRefinePrompt = typeof defaultRelevancyRefinePrompt;
