import type { ServiceContext } from "../ServiceContext.js";
export declare const DEFAULT_PIPELINE_NAME = "default";
export declare const DEFAULT_PROJECT_NAME = "default";
export declare const DEFAULT_BASE_URL = "https://api.cloud.llamaindex.ai";
export type ClientParams = {
    apiKey?: string;
    baseUrl?: string;
};
export type CloudConstructorParams = {
    name: string;
    projectName?: string;
    serviceContext?: ServiceContext;
} & ClientParams;
