import type { NodeWithScore } from "../Node.js";
import type { BaseNodePostprocessor } from "./types.js";
export declare class MetadataReplacementPostProcessor implements BaseNodePostprocessor {
    targetMetadataKey: string;
    constructor(targetMetadataKey: string);
    postprocessNodes(nodes: NodeWithScore[]): Promise<NodeWithScore[]>;
}
