import type { NodeWithScore } from "../../Node.js";
import type { MessageContent } from "../../llm/types.js";
import type { BaseNodePostprocessor } from "../types.js";
type CohereRerankOptions = {
    topN?: number;
    model?: string;
    apiKey: string | null;
};
export declare class CohereRerank implements BaseNodePostprocessor {
    topN: number;
    model: string;
    apiKey: string | null;
    private client;
    /**
     * Constructor for CohereRerank.
     * @param topN Number of nodes to return.
     */
    constructor({ topN, model, apiKey, }: CohereRerankOptions);
    /**
     * Reranks the nodes using the Cohere API.
     * @param nodes Array of nodes with scores.
     * @param query Query string.
     */
    postprocessNodes(nodes: NodeWithScore[], query?: MessageContent): Promise<NodeWithScore[]>;
}
export {};
