import type { PlatformApi } from "@llamaindex/cloud";
import { BaseNode } from "../Node.js";
import type { TransformComponent } from "../ingestion/types.js";
export type GetPipelineCreateParams = {
    pipelineName: string;
    pipelineType: any;
    transformations?: TransformComponent[];
    inputNodes?: BaseNode[];
};
export declare function getPipelineCreate(params: GetPipelineCreateParams): Promise<PlatformApi.PipelineCreate>;
