"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "BaseIndexStore", {
    enumerable: true,
    get: function() {
        return BaseIndexStore;
    }
});
const _constants = require("../constants.js");
const defaultPersistPath = `${_constants.DEFAULT_PERSIST_DIR}/${_constants.DEFAULT_INDEX_STORE_PERSIST_FILENAME}`;
class BaseIndexStore {
    async persist(persistPath = defaultPersistPath) {
    // Persist the index store to disk.
    }
}
