/// <reference types="node" resolution-mode="require"/>
import { Document } from "../Node.js";
import { FileReader } from "./type.js";
export declare class DocxReader extends FileReader {
    /** DocxParser */
    loadDataAsContent(fileContent: Buffer): Promise<Document[]>;
}
