import type { JSONValue } from "../types.js";
export declare const isAsyncIterable: (obj: unknown) => obj is AsyncIterable<unknown>;
export declare const isIterable: (obj: unknown) => obj is Iterable<unknown>;
/**
 * Prettify an error for AI to read
 */
export declare function prettifyError(error: unknown): string;
export declare function stringifyJSONToMessageContent(value: JSONValue): string;
