import type { BaseNode, Metadata } from "../../Node.js";
export declare function validateIsFlat(obj: {
    [key: string]: any;
}): void;
export declare function nodeToMetadata(node: BaseNode, removeText?: boolean, textField?: string, flatMetadata?: boolean): Metadata;
type MetadataDictToNodeOptions = {
    fallback: Record<string, any>;
};
export declare function metadataDictToNode(metadata: Metadata, options?: MetadataDictToNodeOptions): BaseNode;
export {};
