export declare function getChunkSize(): number | undefined;
export declare function setChunkSize(chunkSize: number | undefined): void;
export declare function withChunkSize<Result>(embeddedModel: number, fn: () => Result): Result;
