import { Document } from "../Node.js";
import { FileReader } from "./type.js";
/**
 * Read the text of a PDF
 */
export declare class PDFReader extends FileReader {
    loadData(file: string): Promise<Document[]>;
    loadDataAsContent(content: Uint8Array): Promise<Document[]>;
}
