export class FunctionTool {
    _fn;
    _metadata;
    constructor(_fn, _metadata){
        this._fn = _fn;
        this._metadata = _metadata;
    }
    static from(fn, schema) {
        return new FunctionTool(fn, schema);
    }
    get metadata() {
        return this._metadata;
    }
    call(input) {
        return this._fn(input);
    }
}
