import type { SubQuestion } from "./engines/query/types.js";
import type { BaseOutputParser, StructuredOutput } from "./types.js";
/**
 *
 * @param text A markdown block with JSON
 * @returns parsed JSON object
 */
export declare function parseJsonMarkdown(text: string): any;
/**
 * SubQuestionOutputParser is used to parse the output of the SubQuestionGenerator.
 */
export declare class SubQuestionOutputParser implements BaseOutputParser<StructuredOutput<SubQuestion[]>> {
    parse(output: string): StructuredOutput<SubQuestion[]>;
    format(output: string): string;
}
