import { GenerativeModel as VertexGenerativeModel, GenerativeModelPreview as VertexGenerativeModelPreview, type GenerateContentResponse, type ModelParams as VertexModelParams, type StreamGenerateContentResult as VertexStreamGenerateContentResult } from "@google-cloud/vertexai";
import type { GeminiChatStreamResponse, IGeminiSession, VertexGeminiSessionOptions } from "./types.js";
import type { CompletionResponse } from "../types.js";
export declare class GeminiVertexSession implements IGeminiSession {
    private vertex;
    private preview;
    constructor(options?: Partial<VertexGeminiSessionOptions>);
    getGenerativeModel(metadata: VertexModelParams): VertexGenerativeModelPreview | VertexGenerativeModel;
    getResponseText(response: GenerateContentResponse): string;
    getChatStream(result: VertexStreamGenerateContentResult): GeminiChatStreamResponse;
    getCompletionStream(result: VertexStreamGenerateContentResult): AsyncIterable<CompletionResponse>;
}
