"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    GEMINI_BACKENDS: function() {
        return GEMINI_BACKENDS;
    },
    GEMINI_MODEL: function() {
        return GEMINI_MODEL;
    }
});
var GEMINI_BACKENDS;
(function(GEMINI_BACKENDS) {
    GEMINI_BACKENDS["GOOGLE"] = "google";
    GEMINI_BACKENDS["VERTEX"] = "vertex";
})(GEMINI_BACKENDS || (GEMINI_BACKENDS = {}));
var GEMINI_MODEL;
(function(GEMINI_MODEL) {
    GEMINI_MODEL["GEMINI_PRO"] = "gemini-pro";
    GEMINI_MODEL["GEMINI_PRO_VISION"] = "gemini-pro-vision";
    GEMINI_MODEL["GEMINI_PRO_LATEST"] = "gemini-1.5-pro-latest";
    GEMINI_MODEL["GEMINI_PRO_1_5_PRO_PREVIEW"] = "gemini-1.5-pro-preview-0514";
    GEMINI_MODEL["GEMINI_PRO_1_5_FLASH_PREVIEW"] = "gemini-1.5-flash-preview-0514";
    GEMINI_MODEL["GEMINI_PRO_1_5"] = "gemini-1.5-pro-001";
    GEMINI_MODEL["GEMINI_PRO_1_5_FLASH"] = "gemini-1.5-flash-001";
})(GEMINI_MODEL || (GEMINI_MODEL = {}));
