import type { BaseNode } from "../Node.js";
import { TextNode } from "../Node.js";
type TextSplitter = (s: string) => string[];
/**
 * Generates an array of nodes from a document.
 * @param doc
 * @param textSplitter - The text splitter to use.
 * @param includeMetadata - Whether to include metadata in the nodes.
 * @param includePrevNextRel - Whether to include previous and next relationships in the nodes.
 * @returns An array of nodes.
 */
export declare function getNodesFromDocument(doc: BaseNode, textSplitter: TextSplitter, includeMetadata?: boolean, includePrevNextRel?: boolean): TextNode[];
export {};
