import type { JSONSchemaType } from "ajv";
import type { BaseTool, QueryEngine, ToolMetadata } from "../types.js";
export type QueryEngineToolParams = {
    queryEngine: QueryEngine;
    metadata: ToolMetadata<JSONSchemaType<QueryEngineParam>>;
};
export type QueryEngineParam = {
    query: string;
};
export declare class QueryEngineTool implements BaseTool<QueryEngineParam> {
    private queryEngine;
    metadata: ToolMetadata<JSONSchemaType<QueryEngineParam>>;
    constructor({ queryEngine, metadata }: QueryEngineToolParams);
    call({ query }: QueryEngineParam): Promise<string>;
}
