import type { NodeWithScore } from "../Node.js";
import type { BaseNodePostprocessor } from "./types.js";
export declare class SimilarityPostprocessor implements BaseNodePostprocessor {
    similarityCutoff?: number;
    constructor(options?: {
        similarityCutoff?: number;
    });
    postprocessNodes(nodes: NodeWithScore[]): Promise<NodeWithScore<import("../Node.js").Metadata>[]>;
}
