/**
 * The underlying structure of each index.
 */
export declare abstract class IndexStruct {
    indexId: string;
    summary?: string;
    constructor(indexId?: `${string}-${string}-${string}-${string}-${string}`, summary?: undefined);
    toJson(): Record<string, unknown>;
    getSummary(): string;
}
