export declare const DEFAULT_COLLECTION = "data";
export declare const DEFAULT_PERSIST_DIR = "./storage";
export declare const DEFAULT_INDEX_STORE_PERSIST_FILENAME = "index_store.json";
export declare const DEFAULT_DOC_STORE_PERSIST_FILENAME = "doc_store.json";
export declare const DEFAULT_VECTOR_STORE_PERSIST_FILENAME = "vector_store.json";
export declare const DEFAULT_GRAPH_STORE_PERSIST_FILENAME = "graph_store.json";
export declare const DEFAULT_NAMESPACE = "docstore";
export declare const DEFAULT_IMAGE_VECTOR_NAMESPACE = "images";
