import type { JSONSchemaType } from "ajv";
import type { BaseTool, ToolMetadata } from "../types.js";
type WikipediaParameter = {
    query: string;
    lang?: string;
};
export type WikipediaToolParams = {
    metadata?: ToolMetadata<JSONSchemaType<WikipediaParameter>>;
};
export declare class WikipediaTool implements BaseTool<WikipediaParameter> {
    private readonly DEFAULT_LANG;
    metadata: ToolMetadata<JSONSchemaType<WikipediaParameter>>;
    constructor(params?: WikipediaToolParams);
    loadData(page: string, lang?: string): Promise<string>;
    call({ query, lang, }: WikipediaParameter): Promise<string>;
}
export {};
