"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    DEFAULT_BASE_URL: function() {
        return DEFAULT_BASE_URL;
    },
    DEFAULT_PIPELINE_NAME: function() {
        return DEFAULT_PIPELINE_NAME;
    },
    DEFAULT_PROJECT_NAME: function() {
        return DEFAULT_PROJECT_NAME;
    }
});
const DEFAULT_PIPELINE_NAME = "default";
const DEFAULT_PROJECT_NAME = "default";
const DEFAULT_BASE_URL = "https://api.cloud.llamaindex.ai";
