/**
 * Top level types to avoid circular dependencies
 */ "use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "QueryBundle", {
    enumerable: true,
    get: function() {
        return QueryBundle;
    }
});
class QueryBundle {
    queryStr;
    constructor(queryStr){
        this.queryStr = queryStr;
    }
    toString() {
        return this.queryStr;
    }
}
