const defaultCollection = "data";
export class BaseKVStore {
}
export class BaseInMemoryKVStore extends BaseKVStore {
    static fromPersistPath(persistPath) {
        throw new Error("Method not implemented.");
    }
}
