export declare const defaultSingleSelectPrompt: (numChoices: number, contextList: string, queryStr: string) => string;
export type SingleSelectPrompt = typeof defaultSingleSelectPrompt;
export declare const defaultMultiSelectPrompt: (numChoices: number, contextList: string, queryStr: string, maxOutputs: number) => string;
export type MultiSelectPrompt = typeof defaultMultiSelectPrompt;
