import type { PlatformApiClient } from "@llamaindex/cloud";
import type { ClientParams } from "./types.js";
export declare function getAppBaseUrl(baseUrl?: string): string;
export declare function getClient({ apiKey, baseUrl, }?: ClientParams): Promise<PlatformApiClient>;
