import { Document } from "../Node.js";
import { SimpleDirectoryReader as EdgeSimpleDirectoryReader, type SimpleDirectoryReaderLoadDataParams } from "./SimpleDirectoryReader.edge.js";
import type { FileReader } from "./type.js";
export declare const FILE_EXT_TO_READER: Record<string, FileReader>;
/**
 * Read all the documents in a directory.
 * By default, supports the list of file types
 * in the FILE_EXT_TO_READER map.
 */
export declare class SimpleDirectoryReader extends EdgeSimpleDirectoryReader {
    loadData(params: SimpleDirectoryReaderLoadDataParams): Promise<Document[]>;
    loadData(directoryPath: string): Promise<Document[]>;
}
