import type { BaseNode } from "../../Node.js";
export declare function chunkSizeCheck<This extends BaseNode, Args extends any[], Return>(contentGetter: (this: This, ...args: Args) => string, _context: ClassMethodDecoratorContext<This, (this: This, ...args: Args) => Return>): (this: This, ...args: Args) => string;
export declare function lazyInitHash(value: ClassAccessorDecoratorTarget<BaseNode, string>, _context: ClassAccessorDecoratorContext): ClassAccessorDecoratorResult<BaseNode, string>;
