"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "OllamaEmbedding", {
    enumerable: true,
    get: function() {
        return OllamaEmbedding;
    }
});
const _ollama = require("../llm/ollama.js");
class OllamaEmbedding extends _ollama.Ollama {
}
