/**
 * Response is the output of a LLM
 */ export class Response {
    response;
    sourceNodes;
    metadata = {};
    constructor(response, sourceNodes){
        this.response = response;
        this.sourceNodes = sourceNodes || [];
    }
    _getFormattedSources() {
        throw new Error("Not implemented yet");
    }
    toString() {
        return this.response ?? "";
    }
}
