import type { NodeWithScore } from "./Node.js";
/**
 * Response is the output of a LLM
 */
export declare class Response {
    response: string;
    sourceNodes?: NodeWithScore[];
    metadata: Record<string, unknown>;
    constructor(response: string, sourceNodes?: NodeWithScore[]);
    protected _getFormattedSources(): void;
    toString(): string;
}
