export interface AzureOpenAIConfig {
    apiKey?: string;
    endpoint?: string;
    apiVersion?: string;
    deploymentName?: string;
}
export declare function getAzureConfigFromEnv(init?: Partial<AzureOpenAIConfig> & {
    model?: string;
}): AzureOpenAIConfig;
export declare function getAzureBaseUrl(config: AzureOpenAIConfig): string;
export declare function getAzureModel(openAIModel: string): string;
export declare function shouldUseAzure(): string | boolean;
