"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    AnthropicAgent: function() {
        return _anthropic.AnthropicAgent;
    },
    AnthropicAgentWorker: function() {
        return _anthropic.AnthropicAgentWorker;
    },
    OpenAIAgent: function() {
        return _openai.OpenAIAgent;
    },
    OpenAIAgentWorker: function() {
        return _openai.OpenAIAgentWorker;
    },
    ReACTAgentWorker: function() {
        return _react.ReACTAgentWorker;
    },
    ReActAgent: function() {
        return _react.ReActAgent;
    }
});
const _anthropic = require("./anthropic.js");
const _openai = require("./openai.js");
const _react = require("./react.js");
 // todo: ParallelAgent
 // todo: CustomAgent
 // todo: ReactMultiModal
