import { Document } from "../Node.js";
import type { BaseReader, FileReader } from "./type.js";
type ReaderCallback = (category: "file" | "directory", name: string, status: ReaderStatus, message?: string) => boolean;
declare enum ReaderStatus {
    STARTED = 0,
    COMPLETE = 1,
    ERROR = 2
}
export type SimpleDirectoryReaderLoadDataParams = {
    directoryPath: string;
    defaultReader?: FileReader | null;
    fileExtToReader?: Record<string, FileReader>;
    numWorkers?: number;
    overrideReader?: FileReader;
};
/**
 * Read all the documents in a directory.
 * By default, supports the list of file types
 * in the FILE_EXT_TO_READER map.
 */
export declare class SimpleDirectoryReader implements BaseReader {
    private observer?;
    constructor(observer?: ReaderCallback | undefined);
    loadData(params: SimpleDirectoryReaderLoadDataParams): Promise<Document[]>;
    loadData(directoryPath: string): Promise<Document[]>;
    private processFile;
    private doObserverCheck;
}
export {};
