import type { BaseDocumentStore } from "./docStore/types.js";
import type { BaseIndexStore } from "./indexStore/types.js";
import type { VectorStore, VectorStoreByType } from "./vectorStore/types.js";
export interface StorageContext {
    docStore: BaseDocumentStore;
    indexStore: BaseIndexStore;
    vectorStores: VectorStoreByType;
}
type BuilderParams = {
    docStore: BaseDocumentStore;
    indexStore: BaseIndexStore;
    vectorStore: VectorStore;
    vectorStores: VectorStoreByType;
    storeImages: boolean;
    persistDir: string;
};
export declare function storageContextFromDefaults({ docStore, indexStore, vectorStore, vectorStores, storeImages, persistDir, }: Partial<BuilderParams>): Promise<StorageContext>;
export {};
