import type { BaseNode } from "../Node.js";
import { IndexStruct } from "./IndexStruct.js";
export declare enum IndexStructType {
    SIMPLE_DICT = "simple_dict",
    LIST = "list",
    KEYWORD_TABLE = "keyword_table"
}
export declare class IndexDict extends IndexStruct {
    nodesDict: Record<string, BaseNode>;
    type: IndexStructType;
    getSummary(): string;
    addNode(node: BaseNode, textId?: string): void;
    toJson(): Record<string, unknown>;
    delete(nodeId: string): void;
}
export declare function jsonToIndexStruct(json: any): IndexStruct;
export declare class IndexList extends IndexStruct {
    nodes: string[];
    type: IndexStructType;
    addNode(node: BaseNode): void;
    toJson(): Record<string, unknown>;
}
