import type { BaseNode } from "../../Node.js";
import type { BaseDocumentStore } from "../../storage/docStore/types.js";
import type { TransformComponent } from "../types.js";
/**
 * Handle doc store duplicates by checking all hashes.
 */
export declare class DuplicatesStrategy implements TransformComponent {
    private docStore;
    constructor(docStore: BaseDocumentStore);
    transform(nodes: BaseNode[]): Promise<BaseNode[]>;
}
