import { CallbackManager } from "../../callbacks/CallbackManager.js";
export declare function getCallbackManager(): CallbackManager;
export declare function setCallbackManager(callbackManager: CallbackManager): void;
export declare function withCallbackManager<Result>(callbackManager: CallbackManager, fn: () => Result): Result;
