import type { BaseNode } from "../Node.js";
import type { BaseKVStore } from "../storage/kvStore/types.js";
import type { TransformComponent } from "./types.js";
export declare function getTransformationHash(nodes: BaseNode[], transform: TransformComponent): string;
export declare class IngestionCache {
    collection: string;
    cache: BaseKVStore;
    nodesKey: string;
    constructor(collection?: string);
    put(hash: string, nodes: BaseNode[]): Promise<void>;
    get(hash: string): Promise<BaseNode[] | undefined>;
}
