import { type BaseNode, type ImageType } from "../Node.js";
import type { MessageContentDetail } from "../llm/types.js";
import { BaseEmbedding } from "./types.js";
export declare abstract class MultiModalEmbedding extends BaseEmbedding {
    abstract getImageEmbedding(images: ImageType): Promise<number[]>;
    /**
     * Optionally override this method to retrieve multiple image embeddings in a single request
     * @param texts
     */
    getImageEmbeddings(images: ImageType[]): Promise<number[][]>;
    transform(nodes: BaseNode[], _options?: any): Promise<BaseNode[]>;
    getQueryEmbedding(query: MessageContentDetail): Promise<number[] | null>;
}
