export default class Replicate {
    auth;
    userAgent;
    baseUrl;
    fetch;
    accounts;
    collections;
    deployments;
    hardware;
    models;
    predictions;
    trainings;
    webhooks;
}
