import type { ImageType } from "../Node.js";
import { MultiModalEmbedding } from "./MultiModalEmbedding.js";
/**
 * Cloudflare worker doesn't support image embeddings for now
 */
export declare class CloudflareWorkerMultiModalEmbedding extends MultiModalEmbedding {
    getImageEmbedding(images: ImageType): Promise<number[]>;
    getTextEmbedding(text: string): Promise<number[]>;
}
