"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "getImageEmbedModel", {
    enumerable: true,
    get: function() {
        return getImageEmbedModel;
    }
});
async function getImageEmbedModel() {
    if (globalThis.navigator?.userAgent === "Cloudflare-Workers") {
        return (await import("../../embeddings/CloudflareWorkerEmbedding.js")).CloudflareWorkerMultiModalEmbedding;
    } else {
        return (await import("../../embeddings/ClipEmbedding.js")).ClipEmbedding;
    }
}
