import { GeminiSession } from "../llm/gemini/base.js";
import { BaseEmbedding } from "./types.js";
export declare enum GEMINI_EMBEDDING_MODEL {
    EMBEDDING_001 = "embedding-001",
    TEXT_EMBEDDING_004 = "text-embedding-004"
}
/**
 * GeminiEmbedding is an alias for Gemini that implements the BaseEmbedding interface.
 * Note: Vertex SDK currently does not support embeddings
 */
export declare class GeminiEmbedding extends BaseEmbedding {
    model: GEMINI_EMBEDDING_MODEL;
    session: GeminiSession;
    constructor(init?: Partial<GeminiEmbedding>);
    private getEmbedding;
    getTextEmbedding(text: string): Promise<number[]>;
}
