/**
 * Top level types to avoid circular dependencies
 */ export class QueryBundle {
    queryStr;
    constructor(queryStr){
        this.queryStr = queryStr;
    }
    toString() {
        return this.queryStr;
    }
}
