import type { ChatHistory } from "../../ChatHistory.js";
import { Response } from "../../Response.js";
import type { LLM } from "../../llm/index.js";
import type { ChatEngine, ChatEngineParamsNonStreaming, ChatEngineParamsStreaming } from "./types.js";
/**
 * SimpleChatEngine is the simplest possible chat engine. Useful for using your own custom prompts.
 */
export declare class SimpleChatEngine implements ChatEngine {
    chatHistory: ChatHistory;
    llm: LLM;
    constructor(init?: Partial<SimpleChatEngine>);
    chat(params: ChatEngineParamsStreaming): Promise<AsyncIterable<Response>>;
    chat(params: ChatEngineParamsNonStreaming): Promise<Response>;
    reset(): void;
}
