export interface DefaultPromptTemplate {
    contextStr: string;
}
export interface DefaultKeywordExtractorPromptTemplate extends DefaultPromptTemplate {
    keywords: number;
}
export interface DefaultQuestionAnswerPromptTemplate extends DefaultPromptTemplate {
    numQuestions: number;
}
export interface DefaultNodeTextTemplate {
    metadataStr: string;
    content: string;
}
export declare const defaultKeywordExtractorPromptTemplate: ({ contextStr, keywords, }: DefaultKeywordExtractorPromptTemplate) => string;
export declare const defaultTitleExtractorPromptTemplate: ({ contextStr }?: DefaultPromptTemplate) => string;
export declare const defaultTitleCombinePromptTemplate: ({ contextStr }?: DefaultPromptTemplate) => string;
export declare const defaultQuestionAnswerPromptTemplate: ({ contextStr, numQuestions }?: DefaultQuestionAnswerPromptTemplate) => string;
export declare const defaultSummaryExtractorPromptTemplate: ({ contextStr }?: DefaultPromptTemplate) => string;
export declare const defaultNodeTextTemplate: ({ metadataStr, content, }?: {
    metadataStr?: string;
    content?: string;
}) => string;
