import type { BaseOutputParser, StructuredOutput } from "../types.js";
export type Answer = {
    choice: number;
    reason: string;
};
export declare class SelectionOutputParser implements BaseOutputParser<StructuredOutput<Answer[]>> {
    /**
     *
     * @param output
     */
    parse(output: string): StructuredOutput<Answer[]>;
    format(output: string): string;
}
