import { MultiModalEmbedding } from "./MultiModalEmbedding.js";
/**
 * Cloudflare worker doesn't support image embeddings for now
 */ export class CloudflareWorkerMultiModalEmbedding extends MultiModalEmbedding {
    getImageEmbedding(images) {
        throw new Error("Method not implemented.");
    }
    getTextEmbedding(text) {
        throw new Error("Method not implemented.");
    }
}
