"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "CloudflareWorkerMultiModalEmbedding", {
    enumerable: true,
    get: function() {
        return CloudflareWorkerMultiModalEmbedding;
    }
});
const _MultiModalEmbedding = require("./MultiModalEmbedding.js");
class CloudflareWorkerMultiModalEmbedding extends _MultiModalEmbedding.MultiModalEmbedding {
    getImageEmbedding(images) {
        throw new Error("Method not implemented.");
    }
    getTextEmbedding(text) {
        throw new Error("Method not implemented.");
    }
}
