import type { BaseNode } from "../../Node.js";
import type { BaseDocumentStore } from "../../storage/docStore/types.js";
import type { VectorStore } from "../../storage/vectorStore/types.js";
import type { TransformComponent } from "../types.js";
/**
 * Handle docstore upserts by checking hashes and ids.
 * Identify missing docs and delete them from docstore and vector store
 */
export declare class UpsertsAndDeleteStrategy implements TransformComponent {
    protected docStore: BaseDocumentStore;
    protected vectorStores?: VectorStore[];
    constructor(docStore: BaseDocumentStore, vectorStores?: VectorStore[]);
    transform(nodes: BaseNode[]): Promise<BaseNode[]>;
}
