import type { NodeWithScore } from "./Node.js";
import type { ServiceContext } from "./ServiceContext.js";
import type { MessageContent } from "./index.edge.js";
export type RetrieveParams = {
    query: MessageContent;
    preFilters?: unknown;
};
/**
 * Retrievers retrieve the nodes that most closely match our query in similarity.
 */
export interface BaseRetriever {
    retrieve(params: RetrieveParams): Promise<NodeWithScore[]>;
    serviceContext?: ServiceContext;
}
