import { BaseKVStore } from "./types.js";
export type DataType = Record<string, Record<string, any>>;
export declare class SimpleKVStore extends BaseKVStore {
    private data;
    private persistPath;
    constructor(data?: DataType);
    put(key: string, val: any, collection?: string): Promise<void>;
    get(key: string, collection?: string): Promise<any>;
    getAll(collection?: string): Promise<DataType>;
    delete(key: string, collection?: string): Promise<boolean>;
    persist(persistPath: string): Promise<void>;
    static fromPersistPath(persistPath: string): Promise<SimpleKVStore>;
    toDict(): DataType;
    static fromDict(saveDict: DataType): SimpleKVStore;
}
