export type Logger = {
    log: (...args: unknown[]) => void;
    error: (...args: unknown[]) => void;
    warn: (...args: unknown[]) => void;
};
export declare const emptyLogger: Logger;
export declare const consoleLogger: Logger;
