import { SimpleKVStore } from "../kvStore/SimpleKVStore.js";
import { KVDocumentStore } from "./KVDocumentStore.js";
type SaveDict = Record<string, any>;
export declare class SimpleDocumentStore extends KVDocumentStore {
    private kvStore;
    constructor(kvStore?: SimpleKVStore, namespace?: string);
    static fromPersistDir(persistDir?: string, namespace?: string): Promise<SimpleDocumentStore>;
    static fromPersistPath(persistPath: string, namespace?: string): Promise<SimpleDocumentStore>;
    persist(persistPath?: string): Promise<void>;
    static fromDict(saveDict: SaveDict, namespace?: string): SimpleDocumentStore;
    toDict(): SaveDict;
}
export {};
