import type { IndexStruct } from "../../indices/IndexStruct.js";
export declare abstract class BaseIndexStore {
    abstract getIndexStructs(): Promise<IndexStruct[]>;
    abstract addIndexStruct(indexStruct: IndexStruct): Promise<void>;
    abstract deleteIndexStruct(key: string): Promise<void>;
    abstract getIndexStruct(structId?: string): Promise<IndexStruct | undefined>;
    persist(persistPath?: string): Promise<void>;
}
