"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "default", {
    enumerable: true,
    get: function() {
        return Replicate;
    }
});
class Replicate {
    auth;
    userAgent;
    baseUrl;
    fetch;
    accounts;
    collections;
    deployments;
    hardware;
    models;
    predictions;
    trainings;
    webhooks;
}
