"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    consoleLogger: function() {
        return consoleLogger;
    },
    emptyLogger: function() {
        return emptyLogger;
    }
});
const emptyLogger = Object.freeze({
    log: ()=>{},
    error: ()=>{},
    warn: ()=>{}
});
const consoleLogger = Object.freeze({
    log: console.log.bind(console),
    error: console.error.bind(console),
    warn: console.warn.bind(console)
});
