type StoredValue = Record<string, any> | null;
export declare abstract class BaseKVStore {
    abstract put(key: string, val: Record<string, any>, collection?: string): Promise<void>;
    abstract get(key: string, collection?: string): Promise<StoredValue>;
    abstract getAll(collection?: string): Promise<Record<string, StoredValue>>;
    abstract delete(key: string, collection?: string): Promise<boolean>;
}
export declare abstract class BaseInMemoryKVStore extends BaseKVStore {
    abstract persist(persistPath: string): void;
    static fromPersistPath(persistPath: string): BaseInMemoryKVStore;
}
export {};
