"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "TextFileReader", {
    enumerable: true,
    get: function() {
        return TextFileReader;
    }
});
const _Node = require("../Node.js");
const _type = require("./type.js");
class TextFileReader extends _type.FileReader {
    async loadDataAsContent(fileContent) {
        const dataBuffer = fileContent.toString("utf-8");
        return [
            new _Node.Document({
                text: dataBuffer
            })
        ];
    }
}
